import Spinner from './Spinner.js';
import SemanticsSchemataComponent from "./frame-components/SemanticsSchemataComponent.js";
import ExamplesComponent from "./frame-components/ExamplesComponent.js";
import SlowalFrameComponent from "./frame-components/SlowalFrameComponent.js";


export default {
  components: { Spinner, SemanticsSchemataComponent, ExamplesComponent, SlowalFrameComponent },
  props: {
    entryId: Number,
    lexicalUnitId: Number
  },
  data() {
    return { frame: null, unifiedFrame: undefined, gettext: window.gettext, hasPermission: window.has_permission,
      subentries: null,
      alternations: null,
      realisation_phrases: null,
      realisation_descriptions: null,
      examples: null,
    }
  },
  emits: ['refresh', 'refreshEntriesList'],
  methods: {
    goToEdit (unifiedFrameId, entryId, lexicalUnitId) {
      window.location = `/${lang}/entries/unification?unified_frame_id=${unifiedFrameId}&entry_id=${entryId}&lexical_unit_id=${lexicalUnitId}`;
    },
    take () {
      $.ajax({
        type     : 'post',
        url      : `/${lang}/unifier/frame_assign/${this.lexicalUnitId}/`,
        dataType : 'json',
        timeout  : 60000,
        success: function (response) {
          show_info('Rama została stworzona oraz przypisana użytkownikowi.');
          this.goToEdit(response.unified_frame_id, this.entryId, this.lexicalUnitId);
        }.bind(this),
        error: function (request, errorType, errorMessage) {
          show_error(errorType + ' (' + errorMessage + ')');
        }
      });
    },
    statusChange(api_method) {
      $.ajax({
        type: 'post',
        url: `/${lang}/semantics/${api_method}/${this.frame.id}/`,
        dataType: 'json',
        timeout: 60000,
      }).then(() => { this.setup(); this.$emit('refreshEntriesList'); });
    },
    markAsInvalid () {
      this.statusChange('frame_mark_as_invalid');
    },
    markAsBad () {
      this.statusChange('frame_mark_as_bad');
    },
    confirmInvalid () {
      this.statusChange('frame_confirm_invalid');
    },
    frame_confirm_as_not_matching_unified_frame () {
      this.statusChange('frame_confirm_as_not_matching_unified_frame');
    },
    rejectInvalid () {
      this.statusChange('frame_reject_invalid');
    },
    frame_reject_as_not_matching_unified_frame () {
      this.statusChange('frame_reject_as_not_matching_unified_frame');
    },
    isReadyToProcess () {
      return (!this.isLeksykograf() && this.unifiedFrame?.status === 'G') || (this.isLeksykograf() && this.frame?.status === 'O');
    },
    isReadyToGet () {
      return this.isLeksykograf() && this.frame?.status === 'N';
    },
    isLeksykograf () {
      return !has_permission("users.view_assignment");
    },
    setup_notes () {
      setup_notes($('#lexical-unit-notes'), $('#lexical-unit-notes-template'), this.lexicalUnitId, 'meanings.LexicalUnit', this.setup_notes);
    },
    setup () {
      $('#lexical-unit-notes').html('');
      get_entry(this.entryId, false, this.lexicalUnitId).then(entry => {
        this.frame = entry.frames[0];
        this.unifiedFrame = entry.unified_frame;
        this.subentries = entry.subentries;
        this.alternations = entry.alternations;
        this.realisation_phrases = entry.realisation_phrases;
        this.realisation_descriptions = entry.realisation_descriptions;
        this.examples = entry.examples;
        setup_notes($('#lexical-unit-notes'), $('#lexical-unit-notes-template'), this.lexicalUnitId, 'meanings.LexicalUnit', this.setup_notes);
      });
    }
  },
  mounted () {
    Split(['#main-frames-pane', '#vue-examples'], {
      direction: 'vertical',
      sizes: [75, 25],
      gutterSize: 4,
      minSize: 10
    });
    Split(['#semantics-frames-pane', '#semantics-schemata-pane'], {
      sizes: [40, 60],
      gutterSize: 4,
      minSize: 10,
      elementStyle: (dimension, size, gutterSize) => {
        return {
          'flex-basis': 'calc(' + size + '% - ' + gutterSize + 'px)'
        }
      },
    });
    this.setup();
  },
  template: `
    <div class="col w-100 p-0 h-100 overflow-auto" id="main-frames-pane" >
      <div class="col h-100 px-1 pt-0 pb-2 overflow-auto" id="semantics-frames-pane">
        <spinner />
<!--        <div id="semantics-frames"></div>-->
        <div id="vue-semantics-frames" v-if="frame">
               <slowal-frame-component :frame="frame" :key="frame"/>
        </div>

        <div class="text-center mb-3">
          <div>
            <a class="btn btn-sm btn-outline-dark mr-2" v-if="frame?.status === 'N'" @click="isLeksykograf() ? markAsInvalid() : markAsBad()">{{ !isLeksykograf() ? gettext('Zła') : gettext('Błędna') }}</a>
            <a class="btn btn-sm btn-outline-dark mr-2" v-if="isReadyToGet() && unifiedFrame === null" @click="take">{{ gettext('Pobierz') }}</a>
            <a
              class="btn btn-sm btn-outline-dark mr-2"
              v-if="isReadyToProcess()"
              @click="goToEdit(this.unifiedFrame.pk, this.entryId, this.lexicalUnitId)"
            >
              {{ isLeksykograf() ? gettext('Obrabiaj') : gettext('Sprawdź') }}
            </a>
            <a
              class="btn btn-sm btn-outline-dark mr-2"
              v-if="frame?.status === 'S' && unifiedFrame?.status === 'S'"
              @click="goToEdit(this.unifiedFrame.pk)"
            >
              {{ gettext('Obejrzyj') }}
            </a>
            <a
              class="btn btn-sm btn-outline-dark mr-2"
              v-if="(frame?.status === 'B' || frame?.status === 'C') && hasPermission('semantics.manage_invalid_lexical_units')"
              @click="frame?.status === 'C' ? frame_confirm_as_not_matching_unified_frame() : confirmInvalid()"
            >
              {{ gettext('Potwierdź') }}
            </a>
            <a
              class="btn btn-sm btn-outline-dark mr-2"
              v-if="(frame?.status === 'B' || frame?.status === 'C') && hasPermission('semantics.manage_invalid_lexical_units')"
              @click="frame?.status === 'C' ? frame_reject_as_not_matching_unified_frame() : rejectInvalid()"
            >
              {{ gettext('Odrzuć') }}
            </a>
          </div>
  <!--        <span v-if="unifiedFrame === null">{{ gettext('Brak ramy unifikacyjnej') }}</span>-->
        </div>
        <div id="lexical-unit-notes"></div>
      </div>
      <div class="col h-100 px-1 pt-0 pb-0 overflow-auto" id="semantics-schemata-pane">
<!--      <semantics-schemata-component -->
<!--        :subentries="subentries"-->
<!--        :key="subentries"-->
<!--        :frame="frame"-->
<!--        :alternations="alternations"-->
<!--        :realisation_phrases="realisation_phrases"-->
<!--        :realisation_descriptions="realisation_descriptions"-->
<!--      />-->
      <div id="semantics-schemata"></div>
    </div>
    </div>
    <div class="col w-100 p-0 tab-pane overflow-auto" id="vue-examples">
        <examples-component
            :examples="examples" 
            :key="examples"
        />
     </div>
  `
}
